@@ -7,7 +7,7 @@ import (
 	"github.com/spf13/cobra"
 	"github.com/twpayne/go-shell"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
+	"github.com/twpayne/chezmoi/internal/chezmoi"
 )
 
 type cdCmdConfig struct {
@@ -26,6 +26,7 @@ func (c *Config) newCDCmd() *cobra.Command {
 		Annotations: newAnnotations(
 			createSourceDirectoryIfNeeded,
 			doesNotRequireValidConfig,
+			persistentStateModeReadWrite,
 			requiresWorkingTree,
 			runsCommands,
 		),
