@@ -60,9 +60,7 @@ func TestLastpassParseNote(t *testing.T) {
 		},
 	} {
 		t.Run(strconv.Itoa(i), func(t *testing.T) {
-			actual, err := lastpassParseNote(tc.note)
-			assert.NoError(t, err)
-			assert.Equal(t, tc.expected, actual)
+			assert.Equal(t, tc.expected, lastpassParseNote(tc.note))
 		})
 	}
 }
