@@ -69,9 +69,7 @@ func TestParseMackupApplication(t *testing.T) {
 		},
 	} {
 		t.Run(tc.name, func(t *testing.T) {
-			actual, err := parseMackupApplication([]byte(chezmoitest.JoinLines(tc.lines...)))
-			assert.NoError(t, err)
-			assert.Equal(t, tc.expected, actual)
+			assert.Equal(t, tc.expected, parseMackupApplication([]byte(chezmoitest.JoinLines(tc.lines...))))
 		})
 	}
 }
