@@ -1,7 +1,6 @@
 package cmd_test
 
 import (
-	"bufio"
 	"bytes"
 	_ "embed"
 	"encoding/hex"
@@ -55,6 +54,7 @@ func TestMain(m *testing.M) {
 	}
 	testscript.Main(m, map[string]func(){
 		"chezmoi": func() {
+			//nolint:revive
 			os.Exit(cmd.Main(cmd.VersionInfo{
 				Version: "v2.0.0+test",
 				Commit:  "HEAD",
@@ -909,18 +909,14 @@ func setup(env *testscript.Env) error {
 // unix2DOS returns data with UNIX line endings converted to DOS line endings.
 func unix2DOS(data []byte) ([]byte, error) {
 	builder := strings.Builder{}
-	scanner := bufio.NewScanner(bytes.NewReader(data))
-	for scanner.Scan() {
-		if _, err := builder.Write(scanner.Bytes()); err != nil {
+	for line := range bytes.Lines(data) {
+		if _, err := builder.Write(line); err != nil {
 			return nil, err
 		}
 		if _, err := builder.WriteString("\r\n"); err != nil {
 			return nil, err
 		}
 	}
-	if err := scanner.Err(); err != nil {
-		return nil, err
-	}
 	return []byte(builder.String()), nil
 }
 
